package api_we

import (
	"dc_golang_server_1/api"
	"dc_golang_server_1/data_db_cache/cache"
	"dc_golang_server_1/logger"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
	"net/http"
	"strconv"
)

// DeleteCardUser 主家长删除一个学生
// @Tags 家长微信
// @Summary  主家长删除一个学生,（当家长点删除时弹框二次确认）
// @Description 传学生ID至后台,后台返回成功失败
// @Produce json
// @Param id path integer true "学生ID"
// @Success 0
// @Router /we/carduser/{id} [DELETE]
// @Security ApiKeyAuth
func DeleteCardUser(c *gin.Context) {
	cardUserID, _ := strconv.Atoi(c.Param("id"))
	if cardUserID == 0 {
		c.JSON(http.StatusOK, gin.H{
			"code":    api.ErrorReqPara,
			"message": api.CodeMsg[api.ErrorReqPara] + " id不正确",
		})
		return
	}
	// 取出微信ID
	weUserID, ok := c.Get("userID")
	if ok == false {
		logger.Log.Error("userID在Context里面居然没填对,遇到鬼了",
			zap.String("Src", "DeleteCardUser"),
			zap.Int("cardUserID", cardUserID))
		c.JSON(http.StatusOK, gin.H{
			"code":    api.ErrorSystemErr,
			"message": api.CodeMsg[api.ErrorSystemErr],
		})
		return
	}
	// 查出该学生信息
	cardUserInfo, ok := cache.GetUCardUserInfo(uint32(cardUserID))
	if ok == false {
		c.JSON(http.StatusOK, gin.H{
			"code":    api.ErrorSystemErr,
			"message": api.CodeMsg[api.ErrorSystemErr],
		})
		return
	}
	if cardUserInfo.MasterWechatUserID != weUserID { // 用户根本没得这个学生的权限，有问题
		c.JSON(http.StatusOK, gin.H{
			"code":    api.ErrorUserRole,
			"message": api.CodeMsg[api.ErrorUserRole],
		})
		return
	}

	// 软删除
	// 先删库

	// 再删缓存

	c.JSON(http.StatusOK, gin.H{
		"code": api.Success,
	})
}
