package dbcurd

import (
	"dc_golang_server_1/logger"
	"go.uber.org/zap"
	"strings"
)

//id integer NOT NULL DEFAULT nextval('b_area_id_seq'::regclass),
//county_id integer,
//name character varying(32) COLLATE pg_catalog."default",
//longitude integer,
//latitude integer,
//status smallint,
//creator_id integer,
//updater_id integer,
//create_at timestamp without time zone,
//update_at timestamp without time zone,
//CONSTRAINT b_area_pkey PRIMARY KEY (id),
//CONSTRAINT b_area_uniq1 UNIQUE (name)

type TableBaseArea struct {
	ID        uint32 `swaggerignore:"true"`
	CountyID  uint32 `json:"county_id" example:"2725"`      // 必填，所属区县ID
	Name      string `json:"name" example:"多彩温江校区"`         // 必填，名字
	Longitude uint32 `json:"longitude" example:"103000000"` // 必填，经度
	Latitude  uint32 `json:"latitude" example:"30000000"`   // 必填，纬度
	Status    uint8  `json:"status" example:"1"`            // 必填，是否测试校区，0预留 1正示 2测试校区
	CreatorID uint32 `json:"creator_id" example:"1"`        // 测试用，以后不传这个字段
	// UpdaterID uint32
	// CreateAt time.Time
	// UpdateAt time.Time
}

func InsertBaseArea(insertData *TableBaseArea) uint8 { //0 成功 1 唯一约束重复 9 系统繁忙
	err := PgDb.QueryRow("INSERT INTO b_area(county_id,name,longitude,latitude,status,creator_id)VALUES($1,$2,$3,$4,$5,$6)RETURNING id",
		insertData.CountyID,
		insertData.Name,
		insertData.Longitude,
		insertData.Latitude,
		insertData.Status,
		insertData.CreatorID,
	).Scan(&insertData.ID)
	if err == nil {
		return 0
	}
	if strings.Contains(err.Error(), "duplicate key value") {
		logger.Log.Error("InsertBaseArea duplicate key value",
			zap.Reflect("insertData", insertData),
			zap.Error(err))
		return 1
	}
	logger.Log.Error("InsertBaseArea Err",
		zap.Reflect("insertData", insertData),
		zap.Error(err))
	return 9
}
