package dbcurd

import (
	"database/sql"
	"dc_golang_server_1/logger"
	"dc_golang_server_1/util/config"
	"fmt"
	_ "github.com/lib/pq"
	"go.uber.org/zap"
)

const ( //0 成功 1 唯一约束重复 9 系统繁忙
	InsertOK        uint8 = 0
	InsertDuplicate uint8 = 1
	InsertSysErr    uint8 = 9
)

var PgDb *sql.DB

var stmtInsertDevConnectRecord *sql.Stmt // 硬件联网流水
var stmtInsertDevCommandRecord *sql.Stmt // 硬件通讯流水
var stmtInsertDevResetRecord *sql.Stmt   // 硬件复位流水
var stmtUpdateWechatUserLogin *sql.Stmt  // 微信登录时间和登录次数更新

func InitDb() {
	var err error
	fmt.Println("DBDSN", config.DbDSN)
	PgDb, err = sql.Open("postgres", config.DbDSN)
	if err != nil {
		panic("数据库连接失败" + err.Error())
	}

	//PgDb.SetConnMaxLifetime()
	//PgDb.SetConnMaxIdleTime()
	//PgDb.SetMaxOpenConns()
	//PgDb.Stats()

	// 硬件通讯流水
	stmtInsertDevCommandRecord, err = PgDb.Prepare("INSERT INTO d_command_record VALUES($1,$2,$3,$4,$5,$6,$7)")
	if err != nil {
		panic("stmtInsertDevCommandRecord:" + err.Error())
	}

	// 硬件联网流水
	stmtInsertDevConnectRecord, err = PgDb.Prepare("INSERT INTO d_connect_record VALUES($1,$2)")
	if err != nil {
		panic("stmtInsertDevConnectRecord:" + err.Error())
	}
	// 硬件复位流水
	stmtInsertDevResetRecord, err = PgDb.Prepare("INSERT INTO d_reset_record VALUES($1,$2,$3,$4,$5,$6,$7)")
	if err != nil {
		panic("stmtInsertDevResetRecord:" + err.Error())
	}

	// 微信登录时间和登录次数更新
	stmtUpdateWechatUserLogin, err = PgDb.Prepare("UPDATE u_we_customer SET login_at=$1,login_count=login_count+1 WHERE id=$2")
	if err != nil {
		panic("建立stmtUpdateWechatUserLogin失败:" + err.Error())
	}
}

func CloseDb() {
	if stmtInsertDevCommandRecord != nil { // 硬件通讯流水
		_ = stmtInsertDevCommandRecord.Close()
	}

	if stmtInsertDevConnectRecord != nil { // 硬件联网流水
		_ = stmtInsertDevConnectRecord.Close()
	}

	if stmtInsertDevResetRecord != nil { // 硬件复位流水
		_ = stmtInsertDevResetRecord.Close()
	}

	if stmtUpdateWechatUserLogin != nil { // 微信登录时间和登录次数更新
		_ = stmtUpdateWechatUserLogin.Close()
	}

	_ = PgDb.Close()
}

func clearTransaction(tx *sql.Tx) {
	err := tx.Rollback()
	if err != sql.ErrTxDone && err != nil {
		logger.Log.Error("clearTransaction",
			zap.Error(err))
	}
}
