package dbcurd

import (
	"dc_golang_server_1/logger"
	"go.uber.org/zap"
	"strings"
)

type InsertTableUCallRecordStruct struct {
	CardUserId     uint32
	DeviceId       uint32
	CallStartAt    string
	CardUserName   string
	SimID          string
	CalledNumber   string
	CalledNickname string
	TalkTime       uint16
	AreaName       string
	AreaServiceID  uint32
	OperatorId     uint32
	Status         uint8
}

func InsertUCallRecordAndUpdateUSimInfo(insertData InsertTableUCallRecordStruct) uint8 { //0 成功 1 唯一约束重复 9 系统繁忙
	tx, err := PgDb.Begin()
	if err != nil {
		logger.Log.Error("InsertUCallRecordAndUpdateUSimInfo PgDb.Begin():",
			zap.Error(err))
		return 9
	}
	defer clearTransaction(tx)
	//先InsertUCallRecord
	_, err = tx.Exec("INSERT INTO u_call_record(card_user_id,device_id,call_start_at,card_user_name,sim_id,called_number,called_nickname,talk_time,area_name,area_service_id,operator_id,status)VALUES($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12)",
		insertData.CardUserId,
		insertData.DeviceId,
		insertData.CallStartAt,
		insertData.CardUserName,
		insertData.SimID,
		insertData.CalledNumber,
		insertData.CalledNickname,
		insertData.TalkTime,
		insertData.AreaName,
		insertData.AreaServiceID,
		insertData.OperatorId,
		insertData.Status,
	)
	if err != nil {
		if strings.Contains(err.Error(), "duplicate key value") { //todoN 这里应考虑去查出来看看内容是不是一样的
			//fmt.Println("InsertUserCallRecord唯一约束重复", err)
			return InsertDuplicate
		}
		logger.Log.Error("InsertUCallRecordAndUpdateUSimInfo InsertUserCallRecord:",
			zap.Error(err))
		return InsertSysErr
	}
	//rowAffected, err := rs.RowsAffected()
	//if err != nil {
	//	fmt.Println("插入电话记录表:rs.RowsAffected()", err)
	//	panic("反正是测试，先退出2")
	//}
	//fmt.Println(rowAffected)

	_, err = tx.Exec("UPDATE u_sim_info SET total_talk_minutes=total_talk_minutes+$1 WHERE card_id=$2", (insertData.TalkTime+59)/60, insertData.SimID)
	if err != nil {
		logger.Log.Error("InsertUCallRecordAndUpdateUSimInfo UPDATE u_sim_info:",
			zap.Error(err))
		return InsertSysErr
	}
	//rowAffected, err = rs.RowsAffected()
	//if err != nil {
	//	fmt.Println("UPDATE u_sim_info:rs.RowsAffected()", err)
	//	panic("反正是测试，先退出4")
	//}
	//fmt.Println(rowAffected)

	if err = tx.Commit(); err != nil {
		logger.Log.Error("InsertUCallRecordAndUpdateUSimInfo Commit:",
			zap.Error(err))
		return InsertSysErr
	}

	return InsertOK
}
