package dbcurd

import (
	"dc_golang_server_1/data_db_cache/model"
	"dc_golang_server_1/logger"
	"fmt"
	"go.uber.org/zap"
	"strings"
	"time"
)

func UpdateUWeCustomerLoginTime(weUserID uint32) { //todoN 以后添加微信登录流水表
	var err error
	for i := 0; i < 10; i++ {
		_, err = stmtUpdateWechatUserLogin.Exec(time.Now().Format("2006-01-02 15:04:05.000"), weUserID) //这里格式化可加可不加
		if err == nil {
			// fmt.Println("res",res)
			return
		}
		fmt.Println("UpdateUWeCustomerLoginTime:", i, err)
		time.Sleep(3 * time.Second)
	}
	logger.Log.Error("UpdateUWeCustomerLoginTime Err",
		zap.Error(err))
}

func InsertUWeCustomerUnionID(unionID string) (id uint32, res uint8) {
	var err error
	for i := 0; i < 10; i++ {
		err = PgDb.QueryRow("INSERT INTO u_we_customer(unionid)VALUES($1)RETURNING id", unionID).Scan(&id)
		if err == nil {
			return // 这里是完全正常的情况
		}
		if strings.Contains(err.Error(), "duplicate key value") {
			logger.Log.Error("InsertUWeCustomerUnionID unionID Err",
				zap.Error(err))
			return 0, InsertDuplicate
		}
		fmt.Println("InsertUWeCustomerUnionID Err:", i, unionID, err)
		time.Sleep(10 * time.Millisecond)
	}
	logger.Log.Error("InsertUWeCustomerUnionID Err",
		zap.Error(err))
	return 0, InsertSysErr
}

func SelectUWeCustomerByUnionIDToCacheModel(unionID string, userInfo *model.CacheUWeCustomerStruct) (userID uint32) {
	// 1. 查u_we_customer表获得基础数据
	err := PgDb.QueryRow("SELECT id,phone,nickname,avatarurl,test_role FROM u_we_customer WHERE unionid=$1", unionID).Scan(
		&userID,
		&userInfo.WePhone,
		&userInfo.Nickname,
		&userInfo.AvatarURL,
		&userInfo.TestRole)
	if err != nil {
		logger.Log.Error("SelectUWeCustomerByUnionIDToCacheModel 1",
			zap.String("unionID", unionID),
			zap.Error(err))
		return 0
	}
	// 2. 查u_we_card_user表,获得绑定的学生数据
	rows, err := PgDb.Query("SELECT card_user_id,master FROM u_we_card_user WHERE we_user_id=$1 order by create_at", userID)
	defer rows.Close()
	if err != nil {
		logger.Log.Error("SelectUWeCustomerByUnionIDToCacheModel 2",
			zap.Uint32("userID", userID),
			zap.Error(err))
		fmt.Println(err)
		return 0
	}
	var cUserID uint32
	var master bool
	userInfo.MasterCardUserID = userInfo.MasterCardUserID[0:0]
	userInfo.SlaveCardUserID = userInfo.SlaveCardUserID[0:0]
	for rows.Next() {
		err = rows.Scan(&cUserID, &master)
		if err != nil {
			logger.Log.Error("SelectUWeCustomerByUnionIDToCacheModel 3",
				zap.Uint32("userID", userID),
				zap.Error(err))
			continue
		}
		if master {
			userInfo.MasterCardUserID = append(userInfo.MasterCardUserID, cUserID)
		} else {
			userInfo.SlaveCardUserID = append(userInfo.SlaveCardUserID, cUserID)
		}
	}
	// 处理完毕后，需要判断一次遍历过程中是否有错误产生
	if err = rows.Err(); err != nil {
		logger.Log.Error("SelectUWeCustomerByUnionIDToCacheModel 4",
			zap.Uint32("userID", userID),
			zap.Error(err))
	}
	return
}

func SelectUWeCustomerByUserIDToCacheModel(userID uint32, userInfo *model.CacheUWeCustomerStruct) (unionID string) {
	// 1. 查u_we_customer表获得基础数据
	err := PgDb.QueryRow("SELECT unionid,phone,nickname,avatarurl,test_role FROM u_we_customer WHERE id=$1", userID).Scan(
		&unionID,
		&userInfo.WePhone,
		&userInfo.Nickname,
		&userInfo.AvatarURL,
		&userInfo.TestRole)
	if err != nil {
		logger.Log.Error("SelectUWeCustomerByUserIDToCacheModel 1",
			zap.Uint32("userID", userID),
			zap.Error(err))
		return ""
	}
	// 2. 查u_we_card_user表,获得绑定的学生数据
	rows, err := PgDb.Query("SELECT card_user_id,master FROM u_we_card_user WHERE we_user_id=$1 order by create_at", userID)
	defer rows.Close()
	if err != nil {
		logger.Log.Error("SelectUWeCustomerByUserIDToCacheModel 2",
			zap.Uint32("userID", userID),
			zap.Error(err))
		return ""
	}
	var cUserID uint32
	var master bool
	userInfo.MasterCardUserID = userInfo.MasterCardUserID[0:0]
	userInfo.SlaveCardUserID = userInfo.SlaveCardUserID[0:0]
	for rows.Next() {
		err = rows.Scan(&cUserID, &master)
		if err != nil {
			logger.Log.Error("SelectUWeCustomerByUserIDToCacheModel 3",
				zap.Uint32("userID", userID),
				zap.Error(err))
			continue
		}
		if master {
			userInfo.MasterCardUserID = append(userInfo.MasterCardUserID, cUserID)
		} else {
			userInfo.SlaveCardUserID = append(userInfo.SlaveCardUserID, cUserID)
		}
	}
	// 处理完毕后，需要判断一次遍历过程中是否有错误产生
	if err = rows.Err(); err != nil {
		logger.Log.Error("SelectUWeCustomerByUserIDToCacheModel 4",
			zap.Uint32("userID", userID),
			zap.Error(err))
	}
	return
}
